<?php
/**
 * @file
 * Logman Admin Settings.
 * Defines configuration settings for logman.
 */

/**
 * Configure the logman settings.
 */
function logman_settings_form() {
  $form = array();
  $form['logman_apache_log_path'] = array(
    '#type' => 'textfield',
    '#title' => t('Apache access log path'),
    '#default_value' => variable_get('logman_apache_log_path', ''),
    '#description' => t("Please provide your server's apache access log path. It will be something like /var/log/httpd/access_log"),
    '#required' => TRUE,
  );

  $form['logman_apache_read_limit'] = array(
    '#type' => 'textfield',
    '#title' => t('Apache access log read limit'),
    '#default_value' => variable_get('logman_apache_read_limit', 100000),
    '#description' => t("Please the limit of character length t you would like to process the apache access log file."),
    '#required' => TRUE,
  );

  $form['logman_items_per_page'] = array(
    '#type' => 'textfield',
    '#title' => t('Log item per page'),
    '#default_value' => variable_get('logman_items_per_page', '30'),
    '#description' => t("Please provide item per page, must be greater or equal to 1."),
    '#required' => TRUE,
  );

  $form['logman_show_page_statistics'] = array(
    '#type' => 'textfield',
    '#title' => t('Show logman page statistics'),
    '#default_value' => variable_get('logman_show_page_statistics', 0),
    '#description' => t("The will display logman page statistics on each page if user has access logman permission. Use '1' to display and '0'  to hide."),
    '#size' => 1,
  );

  $form['logman_page_statistics_duration'] = array(
    '#type' => 'textfield',
    '#title' => t('Logman page statistics duration'),
    '#default_value' => variable_get('logman_page_statistics_duration', 10),
    '#description' => t("The duration of logman page statistics like since 10 days or 10 hours."),
    '#size' => 10,
  );

  $form['logman_page_statistics_duration_unit'] = array(
    '#type' => 'select',
    '#title' => t('Logman page statistics duration unit'),
    '#options' => array(
      'hours' => t('Hours'),
      'days' => t('Days'),
    ),
    '#default_value' => variable_get('logman_page_statistics_duration_unit', 'days'),
    '#description' => t("The unit of duration of logman page statistics, like days or hours."),
  );

  $form['logman_google_chart_api_url'] = array(
    '#type' => 'textfield',
    '#title' => t('Google Chart API URL'),
    '#default_value' => variable_get('logman_google_chart_api_url', 'https://www.google.com/jsapi'),
    '#description' => t("The google chart API URL"),
    '#size' => 100,
  );

  return system_settings_form($form);
}

/**
 * Defining the validation of the settings form.
 */
function logman_settings_form_validate($form, &$form_state) {
  $path = trim($form_state['values']['logman_apache_log_path']);
  $read_limit = trim($form_state['values']['logman_apache_read_limit']);
  $item_per_page = trim($form_state['values']['logman_items_per_page']);

  if ($form_state['values']['op'] == t('Save configuration')) {
    if (!is_readable($path)) {
      form_set_error('logman_apache_log_path', t("The file in apache access log path either doesn't exist or is not readable."));
    }
    if ($item_per_page <= 0) {
      form_set_error('logman_items_per_page', t('Item per page should be greater or equal to 1.'));
    }
    if ($read_limit < 1000) {
      form_set_error('logman_apache_read_limit', t('For proper performance of apache access log search and statistics please enter a value greater than or equal to 1000.'));
    }
  }
}
